/******************************************************************************/

char gVersion[] = "@(#) NcFTP 3.0.4/692 October 25 2001, 10:00 PM             ";

/******************************************************************************/

#ifdef OS
char gOS[] = OS;
#elif defined(WIN32) || defined(_WINDOWS)
char gOS[] = "Windows";
#else
char gOS[] = "UNIX";
#endif

/******************************************************************************/

char gCopyright[] = "@(#) \
Copyright (c) 1992-2001 by Mike Gleason.\n\
All rights reserved.\n\
";

/******************************************************************************/
